# Honeydew
This library is a collection of database and GCP connector for ETL

## Supported connectors and helper functions
* MySQL
* GCP
* SSH
* Utilities
* Notification

## Installation
```
pip install honeydew
```
<br />

## Repository
Source code: 
You can find the documentation [here](https://honeydew-lib.github.io/)!
